@@ -24,6 +24,9 @@ from .DataStruct import *
 
 
 class Events:
+    """
+    模拟事件类。
+    """
     device = None
     app = None
     item = None
@@ -40,35 +43,77 @@ class Events:
         return False
 
     def get_blank_timeout(self) -> int:
+        """
+        获取设备由暗屏状态至灭屏状态的超时时间。\n
+        :return: 时间(单位:秒)
+        """
         return int(self.device.con.get(path="getBlankTimeout").read())
 
     def set_blank_timeout(self, timeout: int) -> bool:
+        """
+        设置设备由暗屏状态至灭屏状态的超时时间。\n
+        :param timeout: 时间(单位:秒)
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="setBlankTimeout", args="sec=" + str(timeout)))
 
     def get_dim_timeout(self) -> int:
+        """
+        获取设备由亮屏状态至暗屏状态的超时时间。\n
+        :return: 时间(单位:秒)
+        """
         return int(self.device.con.get(path="getDimTimeout").read())
 
     def set_dim_timeout(self, timeout: int) -> bool:
+        """
+        设置设备由亮屏状态至暗屏状态的超时时间。\n
+        :param timeout: 时间(单位:秒)
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="setDimTimeout", args="sec=" + str(timeout)))
 
     def set_display_on(self) -> bool:
+        """
+        设置设备屏幕状态为亮屏。\n
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="setDisplayState", args="state=0"))
 
     def set_display_off(self) -> bool:
+        """
+        设置设备屏幕状态为灭屏。\n
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="setDisplayState", args="state=1"))
 
     def set_display_dim(self) -> bool:
+        """
+        设置设备屏幕状态为暗屏。\n
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="setDisplayState", args="state=0")) and \
                self.__reply_status_check(self.device.con.get(path="setDisplayState", args="state=2"))
 
     def get_display_state(self) -> DisplayState:
+        """
+        获取设备当前的屏幕状态。\n
+        :return: DisplayState枚举值
+        """
         reply = int(str(self.device.con.get(path="getDisplayState").read(), 'utf-8'))
         return DisplayState(reply)
 
     def lock(self) -> bool:
+        """
+        将设备锁屏设置为锁定状态。\n
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="setLockState", args="state=0"))
 
     def unlock(self) -> bool:
+        """
+        将设备锁屏设置为解锁状态。\n
+        :return: 成功返回True，否则为False
+        """
         dis_state = int(str(self.device.con.get(path="getDisplayState").read(), 'utf-8'))
         if dis_state == 0 or dis_state == 2:
             return self.__reply_status_check(self.device.con.get(path="setLockState", args="state=1"))
@@ -79,19 +124,37 @@ class Events:
         return False
 
     def get_lock_state(self) -> LockState:
+        """
+        获取设备锁屏当前的锁定状态。\n
+        :return: LockState枚举值
+        """
         reply = int(str(self.device.con.get(path="getLockState").read(), 'utf-8'))
         return LockState(reply)
 
     def submit_string(self, text: str) -> bool:
+        """
+        向当前拥有焦点的元素控件提交文本(模拟输入法事件)。\n
+        :param text: 文本字符串
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="sendCommitString", args="str=" + urllib.parse.quote(text)))
 
-    # def click(self, x: int, y: int, delay: int = 0) -> bool:
-    #     return self.__reply_status_check(self.device.con.get(path="sendTouchEvent", args="points=" + str(x) + "|" + str(y) + "&delay=" + str(delay)))
-
     def click(self, point: Point, delay: int = 0) -> bool:
+        """
+        点击屏幕。\n
+        :param point: 坐标点类Point对象
+        :param delay: 点击延时时间(单位:毫秒)，默认无延时
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="sendTouchEvent", args="points=" + str(point.x) + "|" + str(point.y) + "&delay=" + str(delay)))
 
     def multi_click(self, points: List[Point], delay: int = 0) -> bool:
+        """
+        多指点击屏幕。\n
+        :param points: 坐标点类Point对象列表
+        :param delay: 点击延时时间(单位:毫秒)，默认无延时
+        :return: 成功返回True，否则为False
+        """
         args = ""
         for point in points:
             args += str(point[0].x) + "|" + str(point[1].y)
@@ -100,9 +163,21 @@ class Events:
         return self.__reply_status_check(self.device.con.get(path="sendTouchEvent", args="points=" + args + "&delay=" + str(delay)))
 
     def swipe(self, p1: Point, p2: Point) -> bool:
+        """
+        滑动屏幕。\n
+        :param p1: 坐标点类Point对象，起始点
+        :param p2: 坐标点类Point对象，终点
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="sendSlideEvent", args="sliders=" + str(p1.x) + "|" + str(p1.y) + "->" + str(p2.x) + "|" + str(p2.y)))
 
     def multi_swipe(self, points1: List[Point], points2: List[Point]) -> bool:
+        """
+        多指滑动屏幕。\n
+        :param points1: 坐标点类Point对象列表，起始点
+        :param points2: 坐标点类Point对象列表，终点
+        :return: 成功返回True，否则为False
+        """
         args = ""
         for point1 in points1:
             args += str(point1.x) + "|" + str(point1.y) + "->" + str(points2[points1.index(point1)].x) + "|" + str(points2[points1.index(point1)].y)
@@ -111,12 +186,28 @@ class Events:
         return self.__reply_status_check(self.device.con.get(path="sendSlideEvent", args="sliders=" + args))
 
     def power(self, delay: int = 0) -> bool:
+        """
+        点击设备电源按键。\n
+        :param delay: 点击延时时间(单位:毫秒)，默认无延时
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="sendPowerKeyEvent", args="delay=" + str(delay)))
 
     def back(self, delay: int = 0) -> bool:
+        """
+        点击设备返回按键。\n
+        :param delay: 点击延时时间(单位:毫秒)，默认无延时
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="sendBackKeyEvent", args="delay=" + str(delay)))
 
     def home(self, delay: int = 0, timeout: int = None) -> bool:
+        """
+        点击设备主屏幕按键。\n
+        :param delay: 点击延时时间(单位:毫秒)，默认无延时
+        :param timeout: 超时时间 (单位:秒)，默认为框架超时时间
+        :return: 成功返回True，否则为False
+        """
         if delay > 0:
             return self.__reply_status_check(self.device.con.get(path="sendHomeKeyEvent", args="delay=" + str(delay)))
         if not timeout:
@@ -125,7 +216,7 @@ class Events:
         while int(time.time()) < die_time:
             if self.__reply_status_check(self.device.con.get(path="sendHomeKeyEvent")):
                 self.device.refresh_layout()
-                selector = etree.XML(self.device.xmlStr.encode('utf-8'))
+                selector = etree.XML(self.device.xml_string.encode('utf-8'))
                 if selector.get("sopId") == "home-screen(FAKE_VALUE)":
                     return True
                 else:
@@ -134,33 +225,72 @@ class Events:
         return False
 
     def menu(self, delay: int = 0) -> bool:
+        """
+        点击设备菜单按键。\n
+        :param delay: 点击延时时间(单位:毫秒)，默认无延时
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="sendMenuKeyEvent", args="delay=" + str(delay)))
 
     def volume_up(self, delay: int = 0) -> bool:
+        """
+        点击设备音量上按键。\n
+        :param delay: 点击延时时间(单位:毫秒)，默认无延时
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="sendVolumeUpKeyEvent", args="delay=" + str(delay)))
 
     def volume_down(self, delay: int = 0) -> bool:
+        """
+        点击设备音量下按键。\n
+        :param delay: 点击延时时间(单位:毫秒)，默认无延时
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="sendVolumeDownKeyEvent", args="delay=" + str(delay)))
 
     def set_rotation_allowed(self, allowed: bool = True) -> bool:
+        """
+        设置设备自动旋转屏幕开关状态。\n
+        :param allowed: 开关状态，True为开启，False为关闭
+        :return: 成功返回True，否则为False
+        """
         if allowed:
             return self.__reply_status_check(self.device.con.get(path="setRotationAllowed", args="allowed=1"))
         else:
             return self.__reply_status_check(self.device.con.get(path="setRotationAllowed", args="allowed=0"))
 
     def get_rotation_allowed(self) -> bool:
+        """
+        获取设备自动旋转屏幕开关状态。\n
+        :return: 开关状态，True为开启，False为关闭
+        """
         reply = int(str(self.device.con.get(path="getRotationAllowed").read(), 'utf-8'))
         if reply == 1:
             return True
         return False
 
     def set_orientation(self, orientation: ScreenOrientation) -> bool:
+        """
+        设置设备屏幕方向(需开启设备旋转屏幕开关)。\n
+        :param orientation: ScreenOrientation枚举值
+        :return: 开关状态，True为开启，False为关闭
+        """
         return self.__reply_status_check(self.device.con.get(path="setCurrentOrientation", args="rotation=" + str(orientation.value)))
 
     def get_orientation(self) -> ScreenOrientation:
+        """
+        获取设备屏幕方向。\n
+        :return: ScreenOrientation枚举值
+        """
         return ScreenOrientation(int(str(self.device.con.get(path="getCurrentOrientation").read(), 'utf-8')))
 
     def upload_file(self, file_path: str, remote_path: str) -> bool:
+        """
+        上传文件至设备。\n
+        :param file_path: 控制端原文件路径
+        :param remote_path: 设备中目标路径
+        :return: 成功返回True，否则为False
+        """
         file_name = file_path.split("/")[len(file_path.split("/")) - 1]
         if file_name == "":
             raise Exception('error: the file path format is incorrect, and the transfer folder is not supported')
@@ -179,30 +309,79 @@ class Events:
         return bool(int(str(self.device.con.post(path="upLoadFile", headers=header, data=data).read(), 'utf-8')))
 
     def file_exist(self, file_path: str) -> bool:
+        """
+        判断设备中指定文件是否存在。\n
+        :param file_path: 设备中文件路径
+        :return: 存在返回True，否则为False
+        """
         return bool(int(str(self.device.con.get(path="checkFileExist", args="filename=" + file_path).read(), 'utf-8')))
 
     def dir_exist(self, dir_path: str) -> bool:
+        """
+        判断设备中指定文件夹是否存在。\n
+        :param dir_path: 设备中文件夹路径
+        :return: 存在返回True，否则为False
+        """
         return self.file_exist(dir_path)
 
     def file_remove(self, file_path: str) -> bool:
+        """
+        删除设备中指定文件。\n
+        :param file_path: 设备中文件路径
+        :return: 成功返回True，否则为False
+        """
         return bool(int(str(self.device.con.get(path="fileRemove", args="filename=" + file_path).read(), 'utf-8')))
 
     def dir_remove(self, dir_path: str) -> bool:
+        """
+        删除设备中指定文件夹。\n
+        :param dir_path: 设备中文件夹路径
+        :return: 成功返回True，否则为False
+        """
         return bool(int(str(self.device.con.get(path="dirRemove", args="dirname=" + dir_path).read(), 'utf-8')))
 
     def file_move(self, source_path: str, target_path: str) -> bool:
+        """
+        移动/重命名设备中指定文件。\n
+        :param source_path: 设备中原始文件路径/名称
+        :param target_path: 设备中目标文件路径/名称
+        :return: 成功返回True，否则为False
+        """
         return bool(int(str(self.device.con.get(path="fileMove", args="source=" + source_path + "&target=" + target_path).read(), 'utf-8')))
 
     def dir_move(self, source_path: str, target_path: str) -> bool:
+        """
+        移动/重命名设备中指定文件夹。\n
+        :param source_path: 设备中原始文件夹路径/名称
+        :param target_path: 设备中目标文件夹路径/名称
+        :return: 成功返回True，否则为False
+        """
         return self.file_move(source_path, target_path)
 
     def file_copy(self, source_path: str, target_path: str) -> bool:
+        """
+        复制设备中指定文件。\n
+        :param source_path: 设备中原始文件路径
+        :param target_path: 设备中目标文件路径
+        :return: 成功返回True，否则为False
+        """
         return bool(int(str(self.device.con.get(path="fileCopy", args="source=" + source_path + "&target=" + target_path).read(), 'utf-8')))
 
     def dir_copy(self, source_path: str, target_path: str) -> bool:
+        """
+        复制设备中指定文件夹。\n
+        :param source_path: 设备中原始文件夹路径
+        :param target_path: 设备中目标文件夹路径
+        :return: 成功返回True，否则为False
+        """
         return bool(int(str(self.device.con.get(path="dirCopy", args="source=" + source_path + "&target=" + target_path).read(), 'utf-8')))
 
     def dir_list(self, dir_path: str) -> List[FileInfo]:
+        """
+        获取设备中指定文件夹内的目录信息。\n
+        :param dir_path: 设备中指定路径
+        :return: FileInfo列表
+        """
         json_str = str(self.device.con.get(path="dirList", args="dirname=" + dir_path).read(), 'utf-8')
         json_obj = json.loads(json_str)
         result = []
@@ -223,15 +402,35 @@ class Events:
         return result
 
     def mkdir(self, dir_path: str) -> bool:
+        """
+        在设备中创建一个文件夹。\n
+        :param dir_path: 设备中要创建的文件夹路径
+        :return: 成功返回True，否则为False
+        """
         return bool(int(str(self.device.con.get(path="mkdir", args="dirname=" + dir_path).read(), 'utf-8')))
 
     def is_installed(self, sopid: str) -> bool:
+        """
+        判断指定应用是否已安装。\n
+        :param sopid: 指定应用的sopid
+        :return: 已安装返回True，否则为False
+        """
         return bool(int(str(self.device.con.get(path="isAppInstalled", args="sopid=" + sopid).read(), 'utf-8')))
 
     def is_uninstallable(self, sopid: str) -> bool:
+        """
+        判断指定应用是否允许卸载。\n
+        :param sopid: 指定应用的sopid
+        :return: 允许卸载返回True，否则为False
+        """
         return bool(int(str(self.device.con.get(path="isAppUninstallable", args="sopid=" + sopid).read(), 'utf-8')))
 
     def install(self, file_path: str) -> bool:
+        """
+        安装应用。\n
+        :param file_path: 控制端.sop文件的路径
+        :return: 成功返回True，否则为False
+        """
         if self.upload_file(file_path, "/tmp/"):
             file_name = file_path.split("/")[len(file_path.split("/")) - 1]
             self.device.con.get(path="install", args="filepath=/tmp/" + file_name)
@@ -239,40 +438,91 @@ class Events:
         return False
 
     def uninstall(self, sopid: str) -> bool:
+        """
+        卸载应用。\n
+        :param sopid: 要卸载的应用sopid
+        :return: 成功返回True，否则为False
+        """
         return bool(int(str(self.device.con.get(path="uninstall", args="sopid=" + sopid).read(), 'utf-8')))
 
     def system_time(self) -> int:
+        """
+        获取设备系统时间。\n
+        :return: unix时间戳(自1970年1月1日0点0分0秒至今的总秒数)
+        """
         return int(str(self.device.con.get(path="getDatetime").read(), 'utf-8'))
 
     def set_system_time(self, secs: int) -> bool:
+        """
+        设置设备系统时间。\n
+        :param secs: unix时间戳(自1970年1月1日0点0分0秒至今的总秒数)
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="setDatetime", args="datetime=" + str(secs)))
 
     def get_system_auto_time(self) -> bool:
+        """
+        获取设备自动获取时间功能的开关状态。\n
+        :return: 开启返回True，否则为False
+        """
         return bool(int(str(self.device.con.get(path="getAutoDatetime").read(), 'utf-8')))
 
     def set_system_auto_time(self, state: bool) -> bool:
+        """
+        设置设备自动获取时间功能的开关状态。\n
+        :param state: 开关状态，开启为True，关闭为False
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="setAutoDatetime", args="state=" + str(int(state))))
 
     def latest_toast(self) -> str:
+        """
+        获取系统最新一次弹出的toast文本(设备会自动清除已被读取或覆盖的toast信息)\n
+        :return: 文本字符串
+        """
         return str(self.device.con.get(path="getLatestToast").read(), 'utf-8')
 
     def clear_app_data(self, sopid: str) -> bool:
+        """
+        清除应用数据。\n
+        :param sopid: 应用sopid
+        :return: 成功返回True，否则为False
+        """
         return self.__reply_status_check(self.device.con.get(path="clearAppData", args="sopid=" + sopid))
 
     def get_panel_state(self) -> bool:
+        """
+        获取设备快捷面板展开状态。\n
+        :return: 展开返回True，否则为False
+        """
         return bool(int(str(self.device.con.get(path="getPanelState").read(), 'utf-8')))
 
     def set_panel_open(self) -> bool:
+        """
+        设置设备快捷面板为展开状态。\n
+        :return: 成功返回True，否则为False
+        """
         if not self.get_panel_state():
             return self.__reply_status_check(self.device.con.get(path="setPanelState"))
         return True
 
     def set_panel_close(self) -> bool:
+        """
+        设置设备快捷面板为收起状态。\n
+        :return: 成功返回True，否则为False
+        """
         if self.get_panel_state():
             return self.__reply_status_check(self.device.con.get(path="setPanelState"))
         return True
 
     def launch(self, sopid: str, uiappid: str, timeout: int = None) -> bool:
+        """
+        启动应用。\n
+        :param sopid: 应用sopid
+        :param uiappid: 应用uiappid
+        :param timeout: 超时时间(单位:秒)，默认为框架超时时间
+        :return: 成功返回True，否则为False
+        """
         self.device.refresh_layout()
         self.device.con.get(path="launchApp", args="sopid=" + sopid + "&" + "uiappid=" + uiappid)
         if timeout is None:
@@ -280,19 +530,30 @@ class Events:
         die_time = int(time.time()) + timeout
         while int(time.time()) < die_time:
             self.device.refresh_layout()
-            selector = etree.XML(self.device.xmlStr.encode('utf-8'))
+            selector = etree.XML(self.device.xml_string.encode('utf-8'))
             if selector.get("sopId") == sopid:
                 return True
             self.device.con.get(path="launchApp", args="sopid=" + sopid + "&" + "uiappid=" + uiappid)
             sleep(1)
         return False
 
-    def close(self, sopid: str) -> bool:
-        return self.__reply_status_check(self.device.con.get(path="quitApp", args="sopid=" + sopid))
+    def close(self, sopid: str, uiappid: str) -> bool:
+        """
+        关闭应用。\n
+        :param sopid: 应用sopid
+        :param uiappid: 应用uiappid
+        :return: 成功返回True，否则为False
+        """
+        return self.__reply_status_check(self.device.con.get(path="quitApp", args="sopid=" + sopid + "&uiappid=" + uiappid))
 
     def is_topmost(self, sopid: str) -> bool:
+        """
+        判断指定应用是否显示在屏幕最上层。\n
+        :param sopid: 指定应用的sopid
+        :return: 在最上层返回True，否则为False
+        """
         self.device.refresh_layout()
-        selector = etree.XML(self.device.xmlStr.encode('utf-8'))
+        selector = etree.XML(self.device.xml_string.encode('utf-8'))
         if selector.get("sopId") == sopid:
             return True
         return False
