@@ -53,7 +53,7 @@ class _WorkerThread(threading.Thread):
 
 class Item:
     """
-    元素控件类，通过Device.find_item_by_xpath_key()与Device.find_item_by_xpath()两个结果返回实例化对象，不推荐单独使用。\n
+    元素控件类，通过Device.find_item_by_xpath_key()与Device.find_item_by_xpath()两个接口结果返回实例化对象，不推荐单独使用。\n
     :ivar sopid: 元素控件所在的应用sopid
     :ivar device: 实例化的Device对象
     :ivar node: 对应的xml节点对象
@@ -775,3 +775,10 @@ class Item:
         """
         self.click()
         return self.device.submit_string(text)
+
+    def grab_image_to_base64(self) -> str:
+        """
+        获取元素控件的显示范围截图。\n
+        :return: 截图的base64形态
+        """
+        return self.device.grab_image_to_base64(self.__x, self.__y, self.__width, self.__height, self.__rotation, self.__scale)
